=== added directory '.github'
=== added directory '.github/workflows'
=== added file '.github/workflows/build-linux.yml'
--- .github/workflows/build-linux.yml	1970-01-01 00:00:00 +0000
+++ .github/workflows/build-linux.yml	2021-06-14 12:39:38 +0000
@@ -0,0 +1,44 @@
+# This is a basic workflow to help you get started with Actions
+
+name: Build Linux
+
+# Controls when the action will run. 
+on:
+  # Triggers the workflow on push or pull request events but only for the master branch
+  push:
+    branches: [ marster ]
+  pull_request:
+    branches: [ marster ]
+
+  # Allows you to run this workflow manually from the Actions tab
+  workflow_dispatch:
+
+# A workflow run is made up of one or more jobs that can run sequentially or in parallel
+jobs:
+  # This workflow contains a single job called "build"
+  build:
+    # The type of runner that the job will run on
+    runs-on: ubuntu-latest
+
+    # Steps represent a sequence of tasks that will be executed as part of the job
+    steps:
+      # Checks-out your repository under $GITHUB_WORKSPACE, so your job can access it
+      - uses: actions/checkout@v2
+
+      # Runs a single command using the runners shell
+      - name: Install Packages
+        run: sudo apt install build-essential cmake flex bison git
+
+      - name: Build 
+        uses: lukka/run-cmake@v2.5
+        with:
+          cmakeListsOrSettingsJson: CMakeListsTxtBasic
+          cmakeAppendedArgs: '-DVERIFYPN_Static=ON -DVERIFYPN_MC_Simplification=OFF'
+          cmakeBuildType: Release
+          cmakeGenerator: UnixMakefiles
+          buildDirectory: '${{runner.workspace}}/build'     
+      - name: Upload artifacts 
+        uses: actions/upload-artifact@v2
+        with:
+          name: verifydtapn-linux64
+          path: '${{runner.workspace}}/build/bin/verifypn-linux64'

=== added file '.github/workflows/build-macos.yml'
--- .github/workflows/build-macos.yml	1970-01-01 00:00:00 +0000
+++ .github/workflows/build-macos.yml	2021-06-14 12:39:38 +0000
@@ -0,0 +1,51 @@
+name: Build MacOS
+
+# Controls when the action will run. 
+on:
+  # Triggers the workflow on push or pull request events but only for the master branch
+  push:
+    branches: [ marster ]
+  pull_request:
+    branches: [ marster ]
+
+  # Allows you to run this workflow manually from the Actions tab
+  workflow_dispatch:
+
+# A workflow run is made up of one or more jobs that can run sequentially or in parallel
+jobs:
+  # This workflow contains a single job called "build"
+  build:
+    # The type of runner that the job will run on
+    runs-on: macos-latest
+
+    # Steps represent a sequence of tasks that will be executed as part of the job
+    steps:
+      # Checks-out your repository under $GITHUB_WORKSPACE, so your job can access it
+      - uses: actions/checkout@v2
+
+      # Runs a single command using the runners shell
+      - name: Install Packages
+        run: |
+          brew install flex bison #gcc-9 git cmake 
+        
+      - name: Build 
+        uses: lukka/run-cmake@v2.5
+        with:
+          cmakeListsOrSettingsJson: CMakeListsTxtAdvanced
+          cmakeAppendedArgs: >-
+            -DVERIFYPN_Static=ON 
+            -DVERIFYPN_MC_Simplification=OFF 
+            -DBISON_EXECUTABLE=/usr/local/opt/bison/bin/bison 
+            -DFLEX_EXECUTABLE=/usr/local/opt/flex/bin/flex
+          cmakeBuildType: Release
+          cmakeGenerator: UnixMakefiles
+          buildDirectory: '${{runner.workspace}}/build'
+        env:
+          CC: gcc-9
+          CXX: g++-9
+          
+      - name: Upload artifacts 
+        uses: actions/upload-artifact@v2
+        with:
+          name: verifydtapn-osx64
+          path: '${{runner.workspace}}/build/bin/verifypn-osx64'

=== added file '.github/workflows/build-win.yml'
--- .github/workflows/build-win.yml	1970-01-01 00:00:00 +0000
+++ .github/workflows/build-win.yml	2021-06-14 12:39:38 +0000
@@ -0,0 +1,47 @@
+name: Build Windows (Cross)
+
+# Controls when the action will run. 
+on:
+  # Triggers the workflow on push or pull request events but only for the master branch
+  push:
+    branches: [ marster ]
+  pull_request:
+    branches: [ marster ]
+
+  # Allows you to run this workflow manually from the Actions tab
+  workflow_dispatch:
+
+# A workflow run is made up of one or more jobs that can run sequentially or in parallel
+jobs:
+  # This workflow contains a single job called "build"
+  build:
+    # The type of runner that the job will run on
+    runs-on: ubuntu-latest
+
+    # Steps represent a sequence of tasks that will be executed as part of the job
+    steps:
+      # Checks-out your repository under $GITHUB_WORKSPACE, so your job can access it
+      - uses: actions/checkout@v2
+
+      # Runs a single command using the runners shell
+      - name: Install Packages
+        run: |
+          sudo apt-get install build-essential cmake flex bison git make
+          sudo apt-get install mingw-w64-x86-64-dev mingw-w64-tools g++-mingw-w64-x86-64 wine wine-binfmt
+
+      - name: Build 
+        uses: lukka/run-cmake@v2.5
+        with:
+          cmakeListsOrSettingsJson: CMakeListsTxtAdvanced
+          cmakeAppendedArgs: >-
+            -DCMAKE_TOOLCHAIN_FILE=${{runner.workspace}}/verifypn/toolchain-x86_64-w64-mingw32.cmake
+            -DVERIFYPN_Static=ON 
+            -DVERIFYPN_MC_Simplification=OFF
+          cmakeBuildType: Release
+          cmakeGenerator: UnixMakefiles
+          buildDirectory: '${{runner.workspace}}/build'     
+      - name: Upload artifacts 
+        uses: actions/upload-artifact@v2
+        with:
+          name: verifytapn-win64.exe
+          path: '${{runner.workspace}}/build/bin/verifypn-win64.exe'

